@@ -3,7 +3,9 @@ config = {
         "google.firestore.v1.Firestore": {
             "retry_codes": {
                 "idempotent": ["DEADLINE_EXCEEDED", "INTERNAL", "UNAVAILABLE"],
+                "aborted_unavailable": ["ABORTED", "UNAVAILABLE"],
                 "non_idempotent": [],
+                "idempotent2": ["DEADLINE_EXCEEDED", "UNAVAILABLE"],
             },
             "retry_params": {
                 "default": {
@@ -28,12 +30,12 @@ config = {
             "methods": {
                 "GetDocument": {
                     "timeout_millis": 60000,
-                    "retry_codes_name": "idempotent",
+                    "retry_codes_name": "idempotent2",
                     "retry_params_name": "default",
                 },
                 "ListDocuments": {
                     "timeout_millis": 60000,
-                    "retry_codes_name": "idempotent",
+                    "retry_codes_name": "idempotent2",
                     "retry_params_name": "default",
                 },
                 "CreateDocument": {
@@ -52,10 +54,15 @@ config = {
                     "retry_params_name": "default",
                 },
                 "BatchGetDocuments": {
-                    "timeout_millis": 300000,
+                    "timeout_millis": 60000,
                     "retry_codes_name": "idempotent",
                     "retry_params_name": "streaming",
                 },
+                "BatchWrite": {
+                    "timeout_millis": 60000,
+                    "retry_codes_name": "aborted_unavailable",
+                    "retry_params_name": "default",
+                },
                 "BeginTransaction": {
                     "timeout_millis": 60000,
                     "retry_codes_name": "idempotent",
@@ -77,12 +84,12 @@ config = {
                     "retry_params_name": "streaming",
                 },
                 "Write": {
-                    "timeout_millis": 86400000,
+                    "timeout_millis": 60000,
                     "retry_codes_name": "non_idempotent",
                     "retry_params_name": "streaming",
                 },
                 "Listen": {
-                    "timeout_millis": 86400000,
+                    "timeout_millis": 60000,
                     "retry_codes_name": "idempotent",
                     "retry_params_name": "streaming",
                 },
@@ -91,6 +98,11 @@ config = {
                     "retry_codes_name": "idempotent",
                     "retry_params_name": "default",
                 },
+                "PartitionQuery": {
+                    "timeout_millis": 60000,
+                    "retry_codes_name": "non_idempotent",
+                    "retry_params_name": "default",
+                },
             },
         }
     }
