@@ -57,7 +57,16 @@ GRPC_STATUS_CODE = {
     "DO_NOT_USE": -1,
 }
 _RPC_ERROR_THREAD_NAME = "Thread-OnRpcTerminated"
-_RECOVERABLE_STREAM_EXCEPTIONS = (exceptions.ServiceUnavailable,)
+_RECOVERABLE_STREAM_EXCEPTIONS = (
+    exceptions.Aborted,
+    exceptions.Cancelled,
+    exceptions.Unknown,
+    exceptions.DeadlineExceeded,
+    exceptions.ResourceExhausted,
+    exceptions.InternalServerError,
+    exceptions.ServiceUnavailable,
+    exceptions.Unauthenticated,
+)
 _TERMINATING_STREAM_EXCEPTIONS = (exceptions.Cancelled,)
 
 DocTreeEntry = collections.namedtuple("DocTreeEntry", ["value", "index"])
@@ -204,9 +213,9 @@ class Watch(object):
         self._closing = threading.Lock()
         self._closed = False
 
-        initial_request = firestore_pb2.ListenRequest(
-            database=self._firestore._database_string, add_target=self._targets
-        )
+        self.resume_token = None
+
+        rpc_request = self._get_rpc_request
 
         if ResumableBidiRpc is None:
             ResumableBidiRpc = self.ResumableBidiRpc  # FBO unit tests
@@ -215,7 +224,7 @@ class Watch(object):
             self._api.transport.listen,
             should_recover=_should_recover,
             should_terminate=_should_terminate,
-            initial_request=initial_request,
+            initial_request=rpc_request,
             metadata=self._firestore._rpc_metadata,
         )
 
@@ -243,13 +252,19 @@ class Watch(object):
         self.has_pushed = False
 
         # The server assigns and updates the resume token.
-        self.resume_token = None
         if BackgroundConsumer is None:  # FBO unit tests
             BackgroundConsumer = self.BackgroundConsumer
 
         self._consumer = BackgroundConsumer(self._rpc, self.on_snapshot)
         self._consumer.start()
 
+    def _get_rpc_request(self):
+        if self.resume_token is not None:
+            self._targets["resume_token"] = self.resume_token
+        return firestore_pb2.ListenRequest(
+            database=self._firestore._database_string, add_target=self._targets
+        )
+
     @property
     def is_active(self):
         """bool: True if this manager is actively streaming.
